@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/apps/qmcrover/DwmMcroverCurrentWeatherWidget.cc 11932 $
-// @(#) $Id: DwmMcroverCurrentWeatherWidget.cc 11932 2022-04-11 02:01:48Z dwm $
+// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/apps/qmcrover/DwmMcroverCurrentWeatherWidget.cc 12387 $
+// @(#) $Id: DwmMcroverCurrentWeatherWidget.cc 12387 2024-06-04 23:31:00Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2020
+//  Copyright (c) Daniel W. McRobb 2020, 2024
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@
 #include "DwmSvnTag.hh"
 #include "DwmMcroverCurrentWeatherWidget.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/apps/qmcrover/DwmMcroverCurrentWeatherWidget.cc 11932 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/apps/qmcrover/DwmMcroverCurrentWeatherWidget.cc 12387 $");
 
 namespace Dwm {
 
@@ -72,7 +72,11 @@ namespace Dwm {
       _stationLabel = new QLabel("----");
       _stationLabel->setStyleSheet("color: #ffff80;");
       QFont  font = _stationLabel->font();
+#ifdef __linux__
+      font.setPointSize(24);
+#else
       font.setPointSize(28);
+#endif
       QFont  bigFont = font;
       bigFont.setPointSize(72);
 
