@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/apps/qmcrover/DwmMcroverStackedWidget.cc 11942 $
-// @(#) $Id: DwmMcroverStackedWidget.cc 11942 2022-04-17 04:05:11Z dwm $
+// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/apps/qmcrover/DwmMcroverStackedWidget.cc 12387 $
+// @(#) $Id: DwmMcroverStackedWidget.cc 12387 2024-06-04 23:31:00Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2020
+//  Copyright (c) Daniel W. McRobb 2020, 2024
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -106,6 +106,13 @@ namespace Dwm {
       return;
     }
 
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    static std::deque<std::string>  sg_pages = {
+      "alertPage", "nwsRadarPage", "weatherPage"
+    };
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -116,9 +123,13 @@ namespace Dwm {
         if (pw) {
           pw->setStyleSheet("background-color: #400000;");
         }
-        if (UserInactive(30)) {
-          pageByName("alertPage");
+      }
+      if (UserInactive(30)) {
+        std::rotate(sg_pages.begin(), sg_pages.begin() + 1, sg_pages.end());
+        if (alerts->empty() && (sg_pages.front() == "alertPage")) {
+          std::rotate(sg_pages.begin(), sg_pages.begin() + 1, sg_pages.end());
         }
+        pageByName(sg_pages.front().c_str());
       }
       return;
     }
@@ -128,14 +139,10 @@ namespace Dwm {
     //------------------------------------------------------------------------
     void StackedWidget::noAlerts()
     {
-      static  std::deque<std::string>  noAlertPages = {
-        "weatherPage", "nwsRadarPage"
-      };
-      
       if (UserInactive(30)) {
-        pageByName(noAlertPages.front().c_str());
-        std::rotate(noAlertPages.begin(), noAlertPages.begin() + 1,
-                    noAlertPages.end());
+        pageByName(sg_pages.front().c_str());
+        std::rotate(sg_pages.begin(), sg_pages.begin() + 1,
+                    sg_pages.end());
       }
       QWidget  *pw = parentWidget();
       if (pw) {
