@@ -1,8 +1,8 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/apps/qmcrover/main.cc 12048 $
-// @(#) $Id: main.cc 12048 2022-10-24 13:41:59Z dwm $
+// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/apps/qmcrover/main.cc 12387 $
+// @(#) $Id: main.cc 12387 2024-06-04 23:31:00Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2020
+//  Copyright (c) Daniel W. McRobb 2020, 2024
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -62,7 +62,7 @@ using Dwm::Mcrover::AlertTableView, Dwm::Mcrover::AlertFetcher,
   Dwm::Mcrover::MinuteEmitter, Dwm::Mcrover::WeatherPageWidget,
   Dwm::Mcrover::CurrentWeatherWidgetPair, Dwm::Mcrover::NWSRadarPageWidget;
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/apps/qmcrover/main.cc 12048 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/apps/qmcrover/main.cc 12387 $");
 
 static AlertFetcher   *g_alertFetcher = nullptr;
 static WeatherFetcher *g_weatherFetcher = nullptr;
@@ -107,19 +107,6 @@ static void SetRadarURL(NWSRadarPageWidget *nwsRadar,
   return;
 }
 
-//----------------------------------------------------------------------------
-//!  
-//----------------------------------------------------------------------------
-void StopThreads()
-{
-  Syslog(LOG_INFO, "StopThreads() called");
-  exit(0);
-  
-  g_weatherFetcher->Stop();
-  g_minuteEmitter->Stop();
-  g_alertFetcher->Stop();
-}
-
 //----------------------------------------------------------------------------
 //!  
 //----------------------------------------------------------------------------
@@ -135,7 +122,6 @@ int main(int argc, char *argv[])
   myMain->setupUi(mainWindow);
   mainWindow->setWindowTitle("qmcrover");
 
-  // AlertTableView  *alertView = new AlertTableView();
   AlertDataModel  *alertModel = new AlertDataModel();
   myMain->alertTableView->setModel(alertModel);
 
@@ -163,8 +149,7 @@ int main(int argc, char *argv[])
 
     SetRadarURL(myMain->nwsRadar, config.Weather());
 
-    //    myMain->pageButton->setImage(QImage(":/resources/images/dwm_orange_no_margins.svg"));
-        myMain->pageButton->setImage(QImage(":/resources/images/mcrover_mcplex_orange_base.svg"));
+    myMain->pageButton->setImage(QImage(":/resources/images/mcrover_mcplex_orange_base.svg"));
     
     QObject::connect(myMain->pageButton, &PageButton::pressedLeft,
                      myMain->stackedWidget, &StackedWidget::prevPage);
@@ -186,9 +171,8 @@ int main(int argc, char *argv[])
     QObject::connect(&weatherFetcher, &WeatherFetcher::currentConditions,
                      myMain->currentWeather, &CurrentWeatherWidgetPair::Populate,
                      Qt::QueuedConnection);
-
-    QObject::connect(&app, &QApplication::lastWindowClosed,
-                     StopThreads);
+    
+    app.setQuitOnLastWindowClosed(true);
     
     myMain->statusbar->showMessage("mcrover");
     
