@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/classes/src/DwmMcroverUPSTarget.cc 12237 $
-// @(#) $Id: DwmMcroverUPSTarget.cc 12237 2023-10-24 02:33:04Z dwm $
+// @(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/classes/src/DwmMcroverUPSTarget.cc 12374 $
+// @(#) $Id: DwmMcroverUPSTarget.cc 12374 2024-05-31 03:40:15Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020
 //  All rights reserved.
@@ -42,6 +42,7 @@
 
 extern "C" {
   #include <time.h>
+  #include <stdint.h>
   #include <upsclient.h>
 }
 
@@ -51,7 +52,7 @@ extern "C" {
 #include "DwmSysLogger.hh"
 #include "DwmMcroverUPSTarget.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.7/classes/src/DwmMcroverUPSTarget.cc 12237 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/mcplex/mcrover/tags/mcrover-0.1.12/classes/src/DwmMcroverUPSTarget.cc 12374 $");
 
 namespace Dwm {
 
@@ -102,9 +103,10 @@ namespace Dwm {
       if (upscli_tryconnect(&upsConn, _name.c_str(), 3493, 0, &timeOut) == 0) {
         for (const auto & ups : _upses) {
           const char *query[3] = { "VAR", ups.c_str(), "ups.status" };
-#if ((! defined(__linux__)) && (! defined(__APPLE__)))
+#if (! defined(__APPLE__))
           size_t  numAnswers = 0;
 #else
+          //  MacPorts still has older nut-2.7.4
           unsigned int  numAnswers = 0;
 #endif
           char  **answer;
